
__description__ = 'crystalflow, XRD Enhanced Crystal Graph Dataloader'
__author__ = 'Bin Cao, Advanced Materials Thrust, Hong Kong University of Science and Technology (Guangzhou)'
__author_email__ = 'binjacobcao@gmail.com'
__url__ = 'https://github.com/Bin-Cao/CrystalFlow'

import datetime
now = datetime.datetime.now()
formatted_date_time = now.strftime('%Y-%m-%d %H:%M:%S')
   

print('crystalflow, XRD Enhanced Crystal Graph Dataloader')
print('If you need any help, please contact me at github.com/Bin-Cao/CrystalFlow')
print('Executed on :',formatted_date_time, ' | Have a great day.')  
print('='*80)
